Specifications — Breezy 3.0.2dev documentation

Developer Document Catalog (3.0.2dev)

# Specifications

- Revision Properties — An application can set arbitrary per-revision key/value pairs to store app-specific data.

- API versioning — breezy API versioning.

- Apport error reporting — Capture data to report bugs.

- Authentication ring — Configuring authentication.

- Bundles — All about bzr bundles.

- Container format — Notes on a container format for streaming and storing Bazaar data.

- Groupcompress — Notes on the compression technology used in CHK repositories.

- Indices — The index facilities available within breezy.

- Inventories — Tree shape abstraction.

- LCA merge — A nice new merge algorithm.

- Network protocol — Custom network protocol.

- Plugin APIs — APIs plugins should use.

- Repositories — What repositories do and are used for.

- Repository stream — Notes on streaming data for repositories (a layer above the container format).

- Bazaar and case-insensitive file systems — How Bazaar operates on case-insensitive file systems such as commonly found on Windows, USB sticks, etc.

- Development repository formats — How to work with repository formats that are still under development. Contains instructions for those implementing new formats, of course, but also for (bleeding-edge) end users of those formats.

- Knit pack repositories — KnitPack repositories (new in Bazaar 0.92).

- Format feature flags — Allow extending formats with optional features. (new in Bazaar 2.5).